@@ -39,7 +39,7 @@ public:
 	
 
 protected:
-	void paintEvent(QPaintEvent* event) Q_DECL_OVERRIDE;
+	void paintEvent(QPaintEvent* event) override;
 	
 private:
 	bool colorsInitialized;
